@@ -1,3 +1,5 @@
+from abc import abstractmethod
+
 from django.conf import settings
 from django.db import models
 
@@ -43,3 +45,8 @@ class BaseTrackedModel(BaseModel):
     def __init__(self, *args, **kwargs):
         super(BaseTrackedModel, self).__init__(*args, **kwargs)
         # todo update editor
+
+    @abstractmethod
+    @classmethod
+    def get_user_field(cls):
+        raise NotImplemented('Refer user_field to filter')
