@@ -7,9 +7,15 @@ class UserAwareCrudSchema(CrudSchema):
     USER_FIELD = None
 
     def __init__(self, user, *args, **kwargs):
+        if not self.USER_FIELD:
+            raise Error(
+                code=-1, status=HttpStatus.HTTP_405_METHOD_NOT_ALLOWED, field_name='USER_FIELD',
+                message='USER_FIELD missing', description='USER_FIELD missing')
+
         super(UserAwareCrudSchema, self).__init__(*args, **kwargs)
         self.user = user
         print(f'USER: {self.user}')
+
         if not isinstance(self.MODEL_CLASS, BaseTrackedModel):
             raise Error(
                 code=-1, status=HttpStatus.HTTP_405_METHOD_NOT_ALLOWED, field_name='MODEL_CLASS',
